Package: spatialprobit
Version: 1.0.4
Date: 2024-02-07
Title: Spatial Probit Models
Authors@R: c(
  person("Stefan", "Wilhelm", email = "wilhelm@financial.com", role = c("aut", "cre")),
  person("Miguel", "Godinho de Matos", email = "miguelgodinhomatos@cmu.edu", role = "aut")
  )
Imports: stats
Depends: R (>= 1.9.0), Matrix, spdep (>= 1.1-1), spatialreg (>= 1.1-1),
        mvtnorm, tmvtnorm
Encoding: UTF-8
Suggests: RUnit, testthat
Description: A collection of methods for the Bayesian estimation of Spatial Probit, Spatial Ordered Probit and Spatial Tobit Models. Original implementations from the works of 'LeSage and Pace' (2009, ISBN: 1420064258) were ported and adjusted for R, as described in 'Wilhelm and de Matos' (2013) <doi:10.32614/RJ-2013-013>.  
License: GPL (>= 2)
URL: https://www.r-project.org
NeedsCompilation: no
Packaged: 2024-02-08 17:40:30 UTC; stefan
Author: Stefan Wilhelm [aut, cre],
  Miguel Godinho de Matos [aut]
Maintainer: Stefan Wilhelm <wilhelm@financial.com>
Repository: CRAN
Date/Publication: 2024-02-09 08:00:07 UTC
Built: R 4.6.0; ; 2026-04-26 10:30:46 UTC; unix
